Changes
=======

0.3.3
-----

* bdist was still broken, it assumes Python 2 style __init__.py files everywhere

0.3.2
-----

* Fix package pindowns and compatibility < eth-abi==1.3.0

0.3.1
-----

* Position column in a cap table

* Fix accounted supply and % in cap table if ERC-20 lacks proper minting events